@@ -30,7 +30,7 @@ class Convert():
         o = onoObject.MediabyteHashObj()
         result = []
         for item in o: 
-            if search_term in o[item] or search_term in item:
+            if search_term.lower() in o[item].lower() or search_term.lower() in item.lower():
                 exclusive_match = False
                 if exclusive_terms:
 
@@ -106,9 +106,7 @@ class Convert():
         
         with open(omm_filename,'w') as f:
             for item in results2:
-                # NB: Hacky, filtering y.y results (because of faulty .y. mixtape splitting)
-                #m = re.search('^y', item)
-                #if not m:
+
                 f.write('y.' + item)
                 f.write('\n')
 
@@ -125,11 +123,11 @@ class Convert():
         
         with open(omm_filename,'w') as f:
             for item in results2[21:]:
-                # NB: Hacky, filtering y.y results (because of faulty .y. mixtape splitting)
-                m = re.search('^y', item)
-                if not m:
-                    f.write('y.' + item)
-                    f.write('\n')
+                # # NB: Hacky, filtering y.y results (because of faulty .y. mixtape splitting)
+                # m = re.search('^y', item)
+                # if not m:
+                f.write('y.' + item)
+                f.write('\n')
 
 
     def docs():
@@ -226,9 +224,9 @@ class Convert():
 
         res = yno.main(item)
         time_code_list = res[0] # get time code occurrences
-        m = re.findall('\.y\.', item) # test for Mixtape
+        m = re.findall('\.\.', item) # test for Mixtape
         if m: 
-            if len(m) >= 1:  # '.y.' match means Mixtape
+            if len(m) >= 1:  # '..' match means Mixtape
                 answer = 'Mixtape'
         # if no Mixtape match
         elif len(time_code_list) == 1: # 1 time code means Cue
@@ -384,7 +382,7 @@ class Convert():
             if len(parsing_res[1]) > 0:
                 title = parsing_res[1][0]
             else:
-                title = 'My' + type_result
+                title = ""
 
             
 
@@ -393,6 +391,8 @@ class Convert():
                 # Sample hash bit object(s)
                 if len(parsing_res[4]) > 0:
                     mySample = yota.Sample(url=parsing_res[2], time_start=Convert._time_str(parsing_res[0][0]), time_end=Convert._time_str(parsing_res[0][1]), title=title, tags=parsing_res[3], bits=parsing_res[4])
+                elif title == "":
+                    mySample = yota.Sample(url=parsing_res[2], time_start=Convert._time_str(parsing_res[0][0]), time_end=Convert._time_str(parsing_res[0][1]), tags=parsing_res[3])
                 else:
                     mySample = yota.Sample(url=parsing_res[2], time_start=Convert._time_str(parsing_res[0][0]), time_end=Convert._time_str(parsing_res[0][1]), title=title, tags=parsing_res[3])
                 return(mySample)
@@ -400,6 +400,8 @@ class Convert():
                 # Cue has bit object(s)
                 if len(parsing_res[4]) > 0:
                     myCue = yota.Cue(parsing_res[2], time_start=parsing_res[0][0], title=title, tags=parsing_res[3], bits=parsing_res[4])
+                elif title == "":
+                    myCue = yota.Cue(parsing_res[2], time_start=parsing_res[0][0], tags=parsing_res[3])
                 else:
                     myCue = yota.Cue(parsing_res[2], time_start=parsing_res[0][0], title=title, tags=parsing_res[3])
                 return(myCue)
@@ -407,6 +409,8 @@ class Convert():
                 # Yota has bit object(s)
                 if len(parsing_res) == 5:
                     myYota = yota.Yota(parsing_res[2], title=title, tags=parsing_res[3], bits=parsing_res[4])
+                elif title == "":
+                    myYota = yota.Yota(parsing_res[2], tags=parsing_res[3])
                 else:
                     myYota = yota.Yota(parsing_res[2], title=title, tags=parsing_res[3])
                 return(myYota)
@@ -421,7 +425,7 @@ class Convert():
 
             res = yno.main(item)
             time_code_list = res[0] # get time code occurrences
-            m = re.findall('\.y\.', item) # test for Mixtape
+            m = re.findall('\.\.', item) # test for Mixtape
             m2 = re.search('^b\.', item)  # test for Bit.Link
             m3 = re.search('\.mp3\W', item) # test for Bit.Mp3
             # Bit matched
@@ -430,7 +434,7 @@ class Convert():
             elif m2:
                 answer = 'bit.Mp3'
             elif m: 
-                if len(m) >= 1:  # '.y.' match means Mixtape
+                if len(m) >= 1:  # '..' match means Mixtape
                     answer = 'Mixtape'
             # if no Mixtape match
             elif len(time_code_list) == 1: # 1 time code means Cue
@@ -500,14 +504,14 @@ class Convert():
 
         def split_yotas(yotas_str):
 
-            m = re.search('\.y\.', yotas_str)
+            m = re.search('\.\.', yotas_str)
             if m: # check not matching y.youtubehash (hash starting with y)
-                my_list = yotas_str.split('.y.')
+                my_list = yotas_str.split('..')
                 new_list = [my_list[0]]
-                for item in my_list[1:]:
-                    new_str = 'y.' + item
-                    new_list.append(new_str)
-                return(new_list)
+                # for item in my_list[1:]:
+                #     new_str = 'y.' + item
+                #     new_list.append(new_str)
+                return(my_list)
             else:
                 return(yotas_str)
 
